precision lowp float;

varying lowp vec2 textureCoordinate;
uniform sampler2D inputImageTexture;

uniform vec2 u_Size;
uniform float bstep;

#define RADIUS    (3)
#define BLENDCMIN   (-2.)
#define BLENCCMAX   (-1.)
#define DIAMETER    (2*RADIUS+1)
#define SPACESMOOTH (2./1.41)
#define INTENSITYSMOOTH (0.12)

#define EPSILON    (1e-15)
#define LUMWEIGHT   (vec4(0.2126, 0.7152, 0.0722, 0.))

#define INTENSITYSMOOTH2 (INTENSITYSMOOTH*INTENSITYSMOOTH)
#define SPACESMOOTH2 (float(RADIUS*RADIUS)*SPACESMOOTH*SPACESMOOTH)

void main()
{
    vec2 fragCoord = u_Size*textureCoordinate;
    vec4 pixelColor = texture2D(inputImageTexture, textureCoordinate);
    vec4 fragColor = vec4(0.);
    vec4 diff = vec4(0.);
    vec4 color = vec4(0.);
    float sum = 0.;
    float coeff = 0.;

    for (int i = -RADIUS; i <= RADIUS; i++){
        for (int j = -RADIUS; j <= RADIUS; j++){
            color = texture2D(inputImageTexture, (fragCoord+vec2(float(i)*bstep, float(j)*bstep))/u_Size);
            diff = color - pixelColor;
            coeff = exp(-(dot(diff*diff, LUMWEIGHT)/INTENSITYSMOOTH2+float(i*i+j*j)/SPACESMOOTH2));
            fragColor += color*coeff;
            sum += coeff;
        }
    }

    fragColor = fragColor/sum;

    diff = pixelColor - fragColor;
    gl_FragColor = (diff+1.)/2.;
}
